@@ -1,5 +1,5 @@
 package POEx::IRC::Backend;
-$POEx::IRC::Backend::VERSION = '0.030002';
+$POEx::IRC::Backend::VERSION = '0.030003';
 use strictures 2;
 
 use Carp;
@@ -50,7 +50,7 @@ sub get_unpacked_addr {
 }
 
 
-use Moo 2;
+use Moo; use MooX::TypeTiny;
 with 'POEx::IRC::Backend::Role::CheckAvail';
 
 
