@@ -1,10 +1,10 @@
 package POEx::IRC::Backend::Connect;
-$POEx::IRC::Backend::Connect::VERSION = '0.030002';
+$POEx::IRC::Backend::Connect::VERSION = '0.030003';
 use strictures 2;
 use Types::Standard -all;
 
 
-use Moo;
+use Moo; use MooX::TypeTiny;
 with 'POEx::IRC::Backend::Role::Socket',
      'POEx::IRC::Backend::Role::CheckAvail';
 
