@@ -1,8 +1,8 @@
 package POEx::IRC::Backend::Listener;
-$POEx::IRC::Backend::Listener::VERSION = '0.030002';
+$POEx::IRC::Backend::Listener::VERSION = '0.030003';
 use Types::Standard -types;
 
-use Moo;
+use Moo; use MooX::TypeTiny;
 with 'POEx::IRC::Backend::Role::Socket',
      'POEx::IRC::Backend::Role::HasEndpoint';
 
